@@ -32,6 +32,7 @@
    i810AB		7123           
    i810E		7125           
    i815			1132           
+   i845G		2562
 */
 
 
@@ -43,12 +44,14 @@
 #include <asm/io.h>
 #include <asm/param.h>	/* for HZ */
 #include "version.h"
+#include "sensors_compat.h"
 
 MODULE_LICENSE("GPL");
 
-#ifndef PCI_DEVICE_ID_INTEL_82815_2
-#define PCI_DEVICE_ID_INTEL_82815_2   0x1132
-#endif
+/* Not defined by any Linux 2.4 kernel */
+#define PCI_DEVICE_ID_INTEL_82810E_IG	0x7125
+#define PCI_DEVICE_ID_INTEL_82815_CGC	0x1132
+#define PCI_DEVICE_ID_INTEL_82845G_IG	0x2562
 
 /* GPIO register locations */
 #define I810_IOCONTROL_OFFSET 0x5000
@@ -171,6 +174,19 @@ void config_i810(struct pci_dev *dev)
 	}
 }
 
+static void i810_inc(struct i2c_adapter *adapter)
+{
+#ifdef MODULE
+	MOD_INC_USE_COUNT;
+#endif
+}
+
+static void i810_dec(struct i2c_adapter *adapter)
+{
+#ifdef MODULE
+	MOD_DEC_USE_COUNT;
+#endif
+}
 
 static struct i2c_algo_bit_data i810_i2c_bit_data = {
 	.setsda		= bit_i810i2c_setsda,
@@ -183,10 +199,11 @@ static struct i2c_algo_bit_data i810_i2c_bit_data = {
 };
 
 static struct i2c_adapter i810_i2c_adapter = {
-	.owner		= THIS_MODULE,
 	.name		= "I810/I815 I2C Adapter",
 	.id		= I2C_HW_B_I810,
 	.algo_data	= &i810_i2c_bit_data,
+	.inc_use	= i810_inc,
+	.dec_use	= i810_dec,
 };
 
 static struct i2c_algo_bit_data i810_ddc_bit_data = {
@@ -200,10 +217,11 @@ static struct i2c_algo_bit_data i810_ddc_bit_data = {
 };
 
 static struct i2c_adapter i810_ddc_adapter = {
-	.owner		= THIS_MODULE,
 	.name		= "I810/I815 DDC Adapter",
 	.id		= I2C_HW_B_I810,
 	.algo_data	= &i810_ddc_bit_data,
+	.inc_use	= i810_inc,
+	.dec_use	= i810_dec,
 };
 
 
@@ -222,19 +240,19 @@ static struct pci_device_id i810_ids[] __devinitdata = {
 	},
 	{
 		.vendor =	PCI_VENDOR_ID_INTEL,
-		.device =	0x7125,
+		.device =	PCI_DEVICE_ID_INTEL_82810E_IG,
 		.subvendor =	PCI_ANY_ID,
 		.subdevice =	PCI_ANY_ID,
 	},
 	{
 		.vendor =	PCI_VENDOR_ID_INTEL,
-		.device =	PCI_DEVICE_ID_INTEL_82815_2,
+		.device =	PCI_DEVICE_ID_INTEL_82815_CGC,
 		.subvendor =	PCI_ANY_ID,
 		.subdevice =	PCI_ANY_ID,
 	},
 	{
 		.vendor =	PCI_VENDOR_ID_INTEL,
-		.device =	0x2562,
+		.device =	PCI_DEVICE_ID_INTEL_82845G_IG,
 		.subvendor =	PCI_ANY_ID,
 		.subdevice =	PCI_ANY_ID,
 	},
