@@ -117,7 +117,6 @@ static void ddcmon_update_client(struct i2c_client *client);
 
 /* This is the driver that will be inserted */
 static struct i2c_driver ddcmon_driver = {
-	.owner		= THIS_MODULE,
 	.name		= "DDCMON READER",
 	.id		= I2C_DRIVERID_DDCMON,
 	.flags		= I2C_DF_NOTIFY,
@@ -193,8 +192,6 @@ static ctl_table ddcmon_dir_table_template[] = {
 	{0}
 };
 
-static int ddcmon_id = 0;
-
 static int ddcmon_attach_adapter(struct i2c_adapter *adapter)
 {
 	return i2c_detect(adapter, &addr_data, ddcmon_detect);
@@ -260,8 +257,6 @@ int ddcmon_detect(struct i2c_adapter *adapter, int address,
 
 	/* Fill in the remaining client fields and put it in the global list */
 	strcpy(new_client->name, client_name);
-
-	new_client->id = ddcmon_id++;
 	data->valid = 0;
 	init_MUTEX(&data->update_lock);
 
@@ -271,7 +266,8 @@ int ddcmon_detect(struct i2c_adapter *adapter, int address,
 
 	/* Register a new directory entry with module sensors */
 	if ((i = i2c_register_entry(new_client, type_name,
-					ddcmon_dir_table_template)) < 0) {
+					ddcmon_dir_table_template,
+					THIS_MODULE)) < 0) {
 		err = i;
 		goto ERROR4;
 	}
