@@ -103,8 +103,7 @@ SENSORS_INSMOD_1(fscher);
 
 /* Initial limits */
 
-/* For each registered FSCHER, we need to keep some data in memory. That
-   data is pointed to by fscher_list[NR]->data. The structure itself is
+/* For each registered FSCHER, we need to keep some data in memory. It is
    dynamically allocated, at the same time when a new fscher client is
    allocated. */
 struct fscher_data {
@@ -356,7 +355,7 @@ static int fscher_write_value(struct i2c_client *client, u8 reg, u8 value)
   return i2c_smbus_write_byte_data(client, reg, value);
 }
 
-/* Called when we have found a new FSCHER. It should set limits, etc. */
+/* Called when we have found a new FSCHER. */
 static void fscher_init_client(struct i2c_client *client)
 {
   struct fscher_data *data = client->data;
@@ -406,6 +405,7 @@ static void fscher_update_client(struct i2c_client *client)
     data->watchdog[2] = fscher_read_value(client, FSCHER_REG_WDOG_CONTROL);
 
     data->global_event = fscher_read_value(client, FSCHER_REG_EVENT_STATE);
+    data->global_control = fscher_read_value(client, FSCHER_REG_CONTROL);
 
     data->last_updated = jiffies;
     data->valid = 1;                 
