@@ -107,8 +107,7 @@ SENSORS_INSMOD_1(fscpos);
 
 /* Initial limits */
 
-/* For each registered FSCPOS, we need to keep some data in memory. That
-   data is pointed to by fscpos_list[NR]->data. The structure itself is
+/* For each registered FSCPOS, we need to keep some data in memory. It is
    dynamically allocated, at the same time when a new fscpos client is
    allocated. */
 struct fscpos_data {
@@ -223,8 +222,8 @@ static int fscpos_attach_adapter(struct i2c_adapter *adapter)
 	return i2c_detect(adapter, &addr_data, fscpos_detect);
 }
 
-int fscpos_detect(struct i2c_adapter *adapter, int address,
-		unsigned short flags, int kind)
+static int fscpos_detect(struct i2c_adapter *adapter, int address,
+			 unsigned short flags, int kind)
 {
 	int i;
 	struct i2c_client *new_client;
@@ -341,7 +340,7 @@ static int fscpos_write_value(struct i2c_client *client, u8 reg, u8 value)
 	return i2c_smbus_write_byte_data(client, reg, value);
 }
 
-/* Called when we have found a new FSCPOS. It should set limits, etc. */
+/* Called when we have found a new FSCPOS. */
 static void fscpos_init_client(struct i2c_client *client)
 {
 	struct fscpos_data *data = client->data;
