@@ -111,8 +111,7 @@ static inline u8 FAN_TO_REG(long rpm, int div)
    bad. Quite a lot of bookkeeping is done. A real driver can often cut
    some corners. */
 
-/* For each registered LM78, we need to keep some data in memory. That
-   data is pointed to by lm78_list[NR]->data. The structure itself is
+/* For each registered LM78, we need to keep some data in memory. It is
    dynamically allocated, at the same time when a new lm78 client is
    allocated. */
 struct lm78_data {
@@ -256,8 +255,8 @@ static int lm78_attach_adapter(struct i2c_adapter *adapter)
 }
 
 /* This function is called by i2c_detect */
-int lm78_detect(struct i2c_adapter *adapter, int address,
-		unsigned short flags, int kind)
+static int lm78_detect(struct i2c_adapter *adapter, int address,
+		       unsigned short flags, int kind)
 {
 	int i;
 	struct i2c_client *new_client;
@@ -330,6 +329,10 @@ int lm78_detect(struct i2c_adapter *adapter, int address,
 		if (!is_isa
 		    && (lm78_read_value(new_client, LM78_REG_I2C_ADDR) !=
 			address)) goto ERROR1;
+		/* Explicitly prevent the misdetection of Winbond chips */
+		i = lm78_read_value(new_client, 0x4f);
+		if (i == 0xa3 || i == 0x5c)
+			goto ERROR1;
 	}
 
 	/* Determine the chip type. */
@@ -362,7 +365,7 @@ int lm78_detect(struct i2c_adapter *adapter, int address,
 		client_name = "LM79 chip";
 	} else {
 #ifdef DEBUG
-		printk("lm78.o: Internal error: unknown kind (%d)?!?",
+		printk("lm78.o: Internal error: unknown kind (%d)\n",
 		       kind);
 #endif
 		goto ERROR1;
