@@ -67,7 +67,6 @@ static void pca9540_channel(struct i2c_client *client, int operation,
 
 /* This is the driver that will be inserted */
 static struct i2c_driver pca9540_driver = {
-	.owner		= THIS_MODULE,
 	.name		= "PCA9540 chip driver",
 	.flags		= I2C_DF_NOTIFY,
 	.attach_adapter	= pca9540_attach_adapter,
@@ -87,8 +86,6 @@ static ctl_table pca9540_dir_table_template[] = {
 	{0}
 };
 
-static int pca9540_id = 0;
-
 static int pca9540_attach_adapter(struct i2c_adapter *adapter)
 {
 	return i2c_detect(adapter, &addr_data, pca9540_detect);
@@ -126,17 +123,14 @@ int pca9540_detect(struct i2c_adapter *adapter, int address,
 		if ((reg & 0xfa) != 0x00
 		 || reg != i2c_smbus_read_byte(new_client)
 		 || reg != i2c_smbus_read_byte(new_client)
-		 || reg != i2c_smbus_read_byte(new_client)) {
-			err = -ENODEV;
+		 || reg != i2c_smbus_read_byte(new_client))
 			goto ERROR1;
-		}
 	}
 
 	kind = pca9540;
 
 	/* Fill in the remaining client fields and put it into the global list */
 	strcpy(new_client->name, "PCA9540 chip");
-	new_client->id = pca9540_id++;
 	init_MUTEX(&data->update_lock);
 
 	/* Tell the I2C layer a new client has arrived */
@@ -145,7 +139,8 @@ int pca9540_detect(struct i2c_adapter *adapter, int address,
 
 	/* Register a new directory entry with module sensors */
 	if ((i = i2c_register_entry(new_client, "pca9540",
-				    pca9540_dir_table_template)) < 0) {
+				    pca9540_dir_table_template,
+				    THIS_MODULE)) < 0) {
 		err = i;
 		goto ERROR2;
 	}
