@@ -504,11 +504,18 @@
 
 #define SENSORS_LM90_PREFIX "lm90"
 #define SENSORS_ADM1032_PREFIX "adm1032"
+#define SENSORS_LM89_PREFIX "lm89"
 #define SENSORS_LM99_PREFIX "lm99"
 #define SENSORS_LM86_PREFIX "lm86"
 #define SENSORS_MAX6657_PREFIX "max6657"
+#define SENSORS_MAX6658_PREFIX "max6658"
+#define SENSORS_MAX6659_PREFIX "max6659"
 #define SENSORS_ADT7461_PREFIX "adt7461"
 #define SENSORS_MAX6680_PREFIX "max6680"
+#define SENSORS_MAX6681_PREFIX "max6681"
+#define SENSORS_MAX6646_PREFIX "max6646"
+#define SENSORS_MAX6647_PREFIX "max6647"
+#define SENSORS_MAX6649_PREFIX "max6649"
 
 #define SENSORS_LM90_LOCAL_TEMP 51 /* R */
 #define SENSORS_LM90_LOCAL_HIGH 52 /* RW */
@@ -1602,6 +1609,7 @@
 #define SENSORS_IT8712_PREFIX "it8712"
 #define SENSORS_IT8716_PREFIX "it8716"
 #define SENSORS_IT8718_PREFIX "it8718"
+#define SENSORS_IT8720_PREFIX "it8720"
 
 #define SENSORS_IT87_IN0 1 /* R */
 #define SENSORS_IT87_IN1 2 /* R */
@@ -2342,8 +2350,8 @@
 #define SENSORS_F71882FG_TEMP_TYPE(n)		(150 + (n))
 
 /* Fujitsu Siemens Computers Heimdal and Heracles */
-#define SENSORS_FSCHMD_PREFIX		"fscher"
-#define SENSORS_FSCHRC_PREFIX		"fscher"
+#define SENSORS_FSCHMD_PREFIX		"fschmd"
+#define SENSORS_FSCHRC_PREFIX		"fschrc"
 
 /* Note, we start with feature numbers of 60+ to not have any overlapping
    features with the old FSCPOS, FSCSCY and FSCHER feature lists, as the
