@@ -36,6 +36,14 @@ sensors_bus *sensors_config_busses = NULL;
 int sensors_config_busses_count = 0;
 int sensors_config_busses_max = 0;
 
+sensors_proc_chips_entry *sensors_proc_chips = NULL;
+int sensors_proc_chips_count = 0;
+int sensors_proc_chips_max = 0;
+
+sensors_bus *sensors_proc_bus = NULL;
+int sensors_proc_bus_count = 0;
+int sensors_proc_bus_max = 0;
+
 static int sensors_substitute_chip(sensors_chip_name *name,int lineno);
 
 /* Wow, this must be one of the ugliest functions I have ever written.
@@ -55,7 +63,7 @@ static int sensors_substitute_chip(sensors_chip_name *name,int lineno);
    be any decimal i2c bus number. '5e' can be any hexadecimal i2c device
    address, and '10dd' any hexadecimal isa address.
 
-   If '*' is used in prefixes, together with dashes, ambigious parses are
+   If '*' is used in prefixes, together with dashes, ambiguous parses are
    introduced. In that case, the prefix is kept as small as possible.
 
    The 'prefix' part in the result is freshly allocated. All old contents
@@ -73,7 +81,7 @@ int sensors_parse_chip_name(const char *orig_name, sensors_chip_name *res)
 
   /* Play it safe */
   res->busname = NULL;
-  
+
   if (! name)
     sensors_fatal_error("sensors_parse_chip_name","Allocating new name");
   /* First split name in upto four pieces. */
@@ -81,7 +89,7 @@ int sensors_parse_chip_name(const char *orig_name, sensors_chip_name *res)
     *part4++ = '\0';
   if ((part3 = strrchr(name,'-')))
     *part3++ = '\0';
-  if ((part2 = strrchr(name,'-'))) 
+  if ((part2 = strrchr(name,'-')))
     *part2++ = '\0';
 
   /* No dashes found? */
@@ -91,7 +99,7 @@ int sensors_parse_chip_name(const char *orig_name, sensors_chip_name *res)
       res->bus = SENSORS_CHIP_NAME_BUS_ANY;
       res->addr = SENSORS_CHIP_NAME_ADDR_ANY;
       goto SUCCES;
-    } else 
+    } else
       goto ERROR;
   }
 
@@ -102,7 +110,7 @@ int sensors_parse_chip_name(const char *orig_name, sensors_chip_name *res)
     if ((strlen(part4) > 4) || (strlen(part4) == 0))
       goto ERROR;
     res->addr = 0;
-    for (i = 0; ; i++) { 
+    for (i = 0; ; i++) {
       switch (part4[i]) {
       case '0': case '1': case '2': case '3': case '4':
       case '5': case '6': case '7': case '8': case '9':
@@ -136,13 +144,17 @@ DONE:;
     res->bus = SENSORS_CHIP_NAME_BUS_ISA;
     if (part2)
       *(part2-1) = '-';
+  } else if (!strcmp(part3,"pci")) {
+    res->bus = SENSORS_CHIP_NAME_BUS_PCI;
+    if (part2)
+      *(part2-1) = '-';
   } else if (part2 && !strcmp(part2,"i2c") && !strcmp(part3,"*"))
     res->bus = SENSORS_CHIP_NAME_BUS_ANY_I2C;
   else if (part2 && !strcmp(part2,"i2c")) {
     if ((strlen(part3) > 3) || (strlen(part3) == 0))
       goto ERROR;
     res->bus = 0;
-    for (i = 0; ; i++) { 
+    for (i = 0; ; i++) {
       switch (part3[i]) {
       case '0': case '1': case '2': case '3': case '4':
       case '5': case '6': case '7': case '8': case '9':
@@ -166,11 +178,11 @@ DONE2:;
       sensors_fatal_error("sensors_parse_chip_name","Allocating new busname");
   } else
     goto ERROR;
-    
+
   if (!strcmp(name,"*"))
     res->prefix = SENSORS_CHIP_NAME_PREFIX_ANY;
   else if (! (res->prefix = strdup(name)))
-    sensors_fatal_error("sensors_parse_chip_name","Allocating new name");
+    sensors_fatal_error("sensors_parse_chip_name", "Allocating name prefix");
   goto SUCCES;
 
 SUCCES:
@@ -198,7 +210,7 @@ int sensors_parse_i2cbus_name(const char *name, int *res)
   if ((strlen(name) > 3) || (strlen(name) == 0))
     return -SENSORS_ERR_BUS_NAME;
   *res = 0;
-  for (i = 0; ; i++) { 
+  for (i = 0; ; i++) {
     switch (name[i]) {
     case '0': case '1': case '2': case '3': case '4':
     case '5': case '6': case '7': case '8': case '9':
@@ -213,6 +225,8 @@ int sensors_parse_i2cbus_name(const char *name, int *res)
 }
 
 
+#define SENSORS_CHIP_NAME_BUS_IGNORE -42
+
 int sensors_substitute_chip(sensors_chip_name *name,int lineno)
 {
   int i,j;
@@ -222,36 +236,40 @@ int sensors_substitute_chip(sensors_chip_name *name,int lineno)
 
   if (i == sensors_config_busses_count) {
     sensors_parse_error("Undeclared i2c bus referenced",lineno);
-    name->bus = sensors_proc_bus_count;
+    name->bus = SENSORS_CHIP_NAME_BUS_IGNORE;
     return -SENSORS_ERR_BUS_NAME;
   }
 
+  /* We used to compare both the adapter and the algorithm names for
+     bus matching, but Linux 2.6 has no more names for algorithms, and
+     it was redundant anyway. So we now only rely on the adapter name. */
   for (j = 0; j < sensors_proc_bus_count; j++) {
     if (!strcmp(sensors_config_busses[i].adapter,
-                sensors_proc_bus[j].adapter) &&
-        !strcmp(sensors_config_busses[i].algorithm,
-                sensors_proc_bus[j].algorithm)) 
-      break;
+                sensors_proc_bus[j].adapter)) {
+      name->bus = sensors_proc_bus[j].number;
+      return 0;
+    }
   }
 
-  /* Well, if we did not find anything, j = sensors_proc_bus_count; so if
-     we set this chip's bus number to j, it will never be matched. Good. */
-  name->bus = j;
+  /* We did not find a matching bus name, simply ignore this chip
+     config entry. */
+  name->bus = SENSORS_CHIP_NAME_BUS_IGNORE;
   return 0;
 }
 
-      
+
 int sensors_substitute_busses(void)
 {
   int err,i,j,lineno;
   sensors_chip_name_list *chips;
   int res=0;
-  
+
   for(i = 0; i < sensors_config_chips_count; i++) {
     lineno = sensors_config_chips[i].lineno;
     chips = &sensors_config_chips[i].chips;
     for(j = 0; j < chips->fits_count; j++)
       if ((chips->fits[j].bus != SENSORS_CHIP_NAME_BUS_ISA) &&
+          (chips->fits[j].bus != SENSORS_CHIP_NAME_BUS_PCI) &&
           (chips->fits[j].bus != SENSORS_CHIP_NAME_BUS_DUMMY) &&
           (chips->fits[j].bus != SENSORS_CHIP_NAME_BUS_ANY) &&
           (chips->fits[j].bus != SENSORS_CHIP_NAME_BUS_ANY_I2C))
