@@ -618,7 +618,7 @@ static const ChipDescriptor lm87_chip = {
 
 static const char *it87_names[] = {
   SENSORS_IT87_PREFIX, SENSORS_IT8712_PREFIX,
-  SENSORS_IT8716_PREFIX, SENSORS_IT8718_PREFIX, NULL
+  SENSORS_IT8716_PREFIX, SENSORS_IT8718_PREFIX, SENSORS_IT8720_PREFIX, NULL
 };
 
 static const FeatureDescriptor it87_features[] = {
@@ -1429,8 +1429,11 @@ static const ChipDescriptor w83793_chip = {
 /** LM90 **/
 
 static const char *lm90_names[] = {
-  SENSORS_LM90_PREFIX, SENSORS_ADM1032_PREFIX, SENSORS_LM99_PREFIX, SENSORS_LM86_PREFIX,
-  SENSORS_MAX6657_PREFIX, SENSORS_ADT7461_PREFIX, NULL
+  SENSORS_LM90_PREFIX, SENSORS_ADM1032_PREFIX, SENSORS_LM89_PREFIX,
+  SENSORS_LM99_PREFIX, SENSORS_LM86_PREFIX, SENSORS_MAX6657_PREFIX,
+  SENSORS_MAX6658_PREFIX, SENSORS_MAX6659_PREFIX, SENSORS_ADT7461_PREFIX,
+  SENSORS_MAX6680_PREFIX, SENSORS_MAX6681_PREFIX, SENSORS_MAX6646_PREFIX,
+  SENSORS_MAX6647_PREFIX, SENSORS_MAX6649_PREFIX, NULL
 };
 
 static const FeatureDescriptor lm90_features[] = {
